@@ -34,12 +34,7 @@
 
 #include <sys/utsname.h>
 
-#include <X11/Xproto.h>
-#include <X11/Xlibint.h>
-#include <X11/Xlib.h>
-
-
-#include <X11/extensions/record.h> 
+#include "libxnee/x11_files.h"
 
 #include "libxnee/xnee_internal.h"
 #include "libxnee/xnee_strings.h"
@@ -47,7 +42,8 @@
 
 
 
-#define  XNEE_CLI    "cnee"
+#define  XNEE_CLI       "cnee"
+#define  XNEE_CLI_UC    "CNEE"
   
 typedef int xnee_keymask;
 
@@ -99,6 +95,8 @@ enum return_values
     XNEE_WINDOW_POS_ADJ_ERROR     ,
     XNEE_MISSING_ARG       ,
     XNEE_OK_LEAVE          ,
+    XNEE_GRAB_CONFUSION    ,
+    XNEE_PROJECT_SYNTAX_ERROR  ,
     XNEE_LAST_ERROR
   } _return_values;
 
@@ -541,7 +539,7 @@ typedef struct
   Bool     all_clients ;    /*!< True if recording all clients 
 			      (else Xneee recods only future clients) */
   Bool     sync        ;    /*!< True if Record used when replaying */
-  Bool     mode        ;    /*!< Xnee's current mode (RECORDER/REPLAY...)  */
+  unsigned char  mode  ;    /*!< Xnee's current mode (RECORDER/REPLAY/SYNTAX_CHECK...)  */
 
   /*@null@*/ void *plugin_handle  ;        /*!< Handle for the plugin file */
   /*@null@*/ char *plugin_name    ;        /*!< Name of the plugin file */
@@ -624,6 +622,7 @@ xnee_check ( const char *arg, const char *long_arg , const char *short_arg );
 
 
 
+
 #define xnee_print_obsolete_mess(s) fprintf (stderr, s)
 
 
