@@ -49,7 +49,6 @@
 
 
 
-
 /*************************************************************
  * internal functions *
  *************************************************************/
@@ -59,7 +58,7 @@ xnee_expression_handle_replay(xnee_data *xd,
 			      xnee_intercept_data * xindata);
 
 static int
-xnee_expression_handle_settings(xnee_data *xd, char *tmp);
+xnee_expression_handle_settings(xnee_data *xd, char *tmp, int synt_mode);
 
 static int
 xnee_expression_handle_comment(xnee_data *xd, char *tmp);
@@ -117,13 +116,12 @@ xnee_expression_handle_session(xnee_data *xd,
 
 
 
-
   /* Is it a meta string */
   do_continue = xnee_expression_handle_comment(xd, tmp);
   if (do_continue==XNEE_META_DATA) { return (do_continue); }
   
-  /* Is it a setting expression*/
-  do_continue = xnee_expression_handle_settings(xd, tmp);
+  /* Is it a setting expression */
+  do_continue = xnee_expression_handle_settings(xd, tmp, XNEE_CLI_SYNTAX);
   if (do_continue==XNEE_SETTINGS_DATA) { return (do_continue); }
   
   /* Is it an action string */
@@ -169,13 +167,12 @@ xnee_expression_handle_project(xnee_data *xd, char *tmp)
   do_continue = xnee_is_replayable(xd, tmp);
   if (do_continue) { return (XNEE_REPLAY_DATA); }
   
-
   /* Is it a meta string */
   do_continue = xnee_expression_handle_comment(xd, tmp);
   if (do_continue==XNEE_META_DATA) { return (do_continue); }
   
-  /* Is it a setting expression*/
-  do_continue = xnee_expression_handle_settings(xd, tmp);
+  /* Is it a setting expression */
+  do_continue = xnee_expression_handle_settings(xd, tmp, XNEE_XNS_SYNTAX);
   if (do_continue==XNEE_SETTINGS_DATA) { return (do_continue); }
   
   /* Is it an action string */
@@ -277,7 +274,7 @@ xnee_expression_handle_replay(xnee_data *xd,
 
 
 static int
-xnee_expression_handle_settings(xnee_data *xd, char *tmp)
+xnee_expression_handle_settings(xnee_data *xd, char *tmp, int synt_mode)
 {
   #define RANGE_BUF_SIZE 100
   int ret=XNEE_SETTINGS_DATA;  
@@ -290,6 +287,7 @@ xnee_expression_handle_settings(xnee_data *xd, char *tmp)
   int len=0;
   char *my_tmp;
   int   option_key;
+  int args_used ;
 
   if (tmp==NULL)
     {
@@ -307,16 +305,23 @@ xnee_expression_handle_settings(xnee_data *xd, char *tmp)
 
   my_tmp = tmp;
 
-  ret_strptr = xnee_str2strptr(my_tmp, 1);
+  ret_strptr = xnee_str2strptr(my_tmp, synt_mode);
+
 
   if (xnee_is_verbose(xd))
     {
       xnee_print_strptr(ret_strptr);
     }
 
-  option_key = xnee_option2key(xd, ret_strptr);
+  ret = xnee_parse_xns_option(xd, ret_strptr, &args_used) ;
 
-  xnee_free_strptr(ret_strptr);
+  /*  option_key = xnee_option2key(xd, ret_strptr);
+      xnee_free_strptr(ret_strptr);
+      if (option_key==0)
+      {
+      ret = XNEE_OK;
+      }
+  */ 
 
   if (ret==XNEE_OK)
     {
@@ -334,10 +339,10 @@ xnee_expression_handle_comment(xnee_data *xd, char *tmp)
 
   len = strlen(tmp);
 
-  xnee_verbose ((xd, "handling comment: %s\n", tmp));
+  xnee_verbose ((xd, "handling comment: \"%s\"\n", tmp));
   if (!strncmp("#",tmp,1))  /* # META data */
     {
-      xnee_verbose ((xd, "meta data read: %s\n", tmp));
+      xnee_verbose ((xd, "comment data read: %s\n", tmp));
       return XNEE_META_DATA;
     }
   return -1;
@@ -399,8 +404,10 @@ xnee_expression_handle_newwindow(xnee_data *xd, char *tmp)
   int override ;
   char buf[256];
 
+
   xnee_verbose ((xd, "---> xnee_expression_handle_newwindow: %s\n", tmp));
 
+
   if (strncmp(XNEE_NEW_WINDOW_MARK,tmp,strlen(XNEE_NEW_WINDOW_MARK))==0)
     {
       tmp = tmp+strlen(XNEE_NEW_WINDOW_MARK);
@@ -431,6 +438,7 @@ xnee_expression_handle_newwindow(xnee_data *xd, char *tmp)
       XNEE_RETURN_IF_ERR(ret);
       
       xnee_verbose ((xd, "<---  : xnee_expression_handle_newwindow\n"));
+
       return XNEE_NEW_WINDOW_DATA;
     }      
 
@@ -715,6 +723,21 @@ xnee_expression_handle_prim(xnee_data *xd, char *str, xnee_intercept_data * xind
   xindata->u.event.type = 0;
 
   xnee_verbose ((xd, "handling primitive: %s\n", str));
+
+  if (str == NULL)
+    {
+      return 0;
+    }
+
+  /* If NEW-WINDOW string, return */
+  if (strncmp(str,
+	      XNEE_NEW_WINDOW_MARK, 
+	      strlen(XNEE_NEW_WINDOW_MARK)) == 0 )
+    {
+      return 0;
+    }
+
+  /* Skip the leading blanks */
   prim_args = strstr(str," ");
 
   if (prim_args==NULL)
