@@ -22,10 +22,6 @@
  * MA  02110-1301, USA.                                              
  ****/
 
-#include <X11/Xlib.h>
-#include <X11/keysym.h>
-#include <X11/keysymdef.h>
-#include <X11/Xutil.h>
 
 
 #include "libxnee/xnee.h"
