@@ -31,18 +31,6 @@
 /* Standard includes */
 #include <stdio.h>
 
-/* X11 includes */
-#include <X11/Xlib.h>
-#include <X11/Xmd.h>
-#include <X11/Xproto.h>
-#include <X11/Xos.h>
-#include <X11/Xlibint.h>  /* Warning, there be dragons here.... */
-
-/* 
- *  X11 extensions includes 
- */
-#include <X11/extensions/record.h> 
-
 #include "libxnee/xnee.h"
 #include "libxnee/print.h"
 #include "libxnee/xnee_dl.h"
@@ -76,6 +64,7 @@ xnee_do_workaround(xnee_data *xd)
 {
   int ret = XNEE_OK; 
   int active_state;
+
   if ( xnee_is_type_nr_set(xd, XNEE_DELIVERED_EVENT, ReparentNotify))
     {
       xnee_set_new_window_pos(xd);
@@ -83,6 +72,7 @@ xnee_do_workaround(xnee_data *xd)
   else
     {
       active_state = xd->record_setup->active;
+
       xnee_add_to_list2(xd, XNEE_DELIVERED_EVENT, ReparentNotify);
       /* Reset active state, since we don't want to record anything
        * if nothing specified.
@@ -177,6 +167,7 @@ xnee_init_list(struct xnee_range *xr, int size)
   xr->index = 0;
   xr->size  = size;
   xr->data  = (int*) malloc (xr->size*sizeof(int));
+/*   printf (" xr->data = %d\n", xr->data); */
   return XNEE_OK;
 }
 
@@ -185,8 +176,6 @@ xnee_free_ranges(xnee_data *xd)
 {
    int i ; 
 
-/*    printf (" '%s'  delete  need=%d\n", */
-/* 	   __func__, need_init); */
 
    for (i=0;i<XNEE_NR_OF_TYPES;i++)
    {
@@ -235,7 +224,6 @@ xnee_print_list(void)
    int i ; 
    int j ; 
    
-   
    for (i=0;i<XNEE_NR_OF_TYPES;i++)
    {
       printf ("%d:[", i);
@@ -302,12 +290,7 @@ xnee_add_to_list2(xnee_data *xd, int type, int ev)
       }
    }
    xrp->data[xrp->index++]=ev;
-   /*
-   printf (" added %d %d\n",
-	   type, ev);
-   xnee_print_list();
 
-   */
    return XNEE_OK;
 }
 
@@ -403,10 +386,19 @@ xnee_add_range_str (xnee_data *xd, int type, char *range)
 	  xnee_verbose((xd, " --  add_range_str 4\n" ));
 	  ret = xnee_add_to_list2(xd, type, start);
 	}
+      else if ( (start==0) && (stop==0) )
+	{
+	  ret = XNEE_OK;
+	}
+      else
+	{
+	  ret == XNEE_RANGE_FAILURE ;	  
+	}
     }
 
   xnee_verbose((xd, " <-- add_range_str (%d, %d, %s) max range=%d\n", 
 		(int)xd,type, range, xnee_get_max_range(xd)));
+
   return (ret);
 }
 
@@ -536,7 +528,9 @@ xnee_add_range (xnee_data* xd,
    */
   xd->xnee_info.data_ranges[type]++;
   xnee_verbose((xd, "<--- xnee_add_range\n"));
-/*   xnee_unset_verbose(xd); */
+
+/*   xnee_record_print_record_range(xd, stderr); */
+
   return (XNEE_OK);
 }
 
@@ -556,27 +550,43 @@ xnee_parse_range (xnee_data *xd,int type, char *range)
   int ret=0;
   int range_len=strlen(range);
 
+/*  */
+
   xnee_verbose ((xd, "int arg=%d\n", (int)xd));
   xnee_verbose ((xd, "nt arg=%d\n", type));
   xnee_verbose ((xd, "string arg=%s\n", range));
 
-  while ( 1 ) {
-    next=strspn (range, "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_");
-    if (next==0) break; 
-    strncpy(buf,range,next);
-    buf[next]='\0';
-    len =strlen(range);
-    range+=next+1;
-    range_len=range_len - next - 1;
-    xnee_verbose((xd, " -- calling xnee_add_range_str (%d, %d, %s) \n" , (int)xd, type, buf));
+  while ( 1 ) 
+    {
+      next=strspn (range, "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_");
+      if (next==0) 
+	{
+	  ret = XNEE_RANGE_FAILURE;
+	  break; 
+	}
+      strncpy(buf,range,next);
+      buf[next]='\0';
+      len =strlen(range);
+      range+=next+1;
+      range_len=range_len - next - 1;
+      xnee_verbose((xd, " -- calling xnee_add_range_str (%d, %d, %s) \n" , (int)xd, type, buf));
 
-    ret=xnee_add_range_str (xd, type, buf);
-    if (range_len<=0) break;
-    if (ret!=0) return (ret);
-  }
+      ret=xnee_add_range_str (xd, type, buf);
 
+      if (ret == XNEE_RANGE_FAILURE )
+	{
+	  ret = XNEE_RANGE_FAILURE;
+	  break;
+	}
+      if (range_len<=0) 
+	{
+	  break;
+	}
+      if (ret!=XNEE_OK) return (ret);
+    }
+  
   xnee_verbose((xd, "<-- parse_range()\n"));
-  return (0);  
+  return ret;  
 }
 
 
@@ -638,21 +648,21 @@ xnee_set_ranges(xnee_data *xd)
 
    xnee_bsort_all();
    
-   if (xnee_is_recorder(xd)!=False)
+   if (xnee_is_replayer(xd))
      {
        xnee_undo_workaround(xd);
        xnee_do_workaround(xd);
      }
 
-   
-   
    for (j=0; j<XNEE_NR_OF_TYPES ;j++)
      {
       first = -1;
       last  = -1;
 
+   
       for (i=0; i<xrs->type[j].index ;i++)
 	{
+
 	  this = xrs->type[j].data[i] ;
 	  
 	  if (first == -1)
@@ -690,6 +700,7 @@ xnee_set_ranges(xnee_data *xd)
 	    }
 	}
    } 
+
    return XNEE_OK;
 }
 
@@ -710,8 +721,6 @@ xnee_rem_from_list(xnee_data *xd, int type, int ev)
 
    xrp = &xrs->type[type];
 
-   xnee_print_list();
-    
 
    for (i=0;i<xrp->index;i++)
    {
