@@ -24,8 +24,6 @@
  ****/
 
 
-#include <X11/extensions/XTest.h>
-
 #include "libxnee/xnee.h"
 #include "libxnee/print.h"
 #include "libxnee/xnee_record.h"
@@ -72,7 +70,6 @@ xnee_delta_time ( xnee_intercept_data * xindata)
 
 
 
-
 /**************************************************************
  *                                                            *
  * xnee_replay_synchronize                                    *
@@ -91,7 +88,6 @@ xnee_replay_synchronize (xnee_data* xd)
       xnee_verbose((xd, "Xnee in NO SYNC mode\n"));
       return XNEE_OK;
     }
-   
 
   /*****
    * Check to see if we are in sync
@@ -224,7 +220,6 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
        while ( (logread != 0)  && ( xd->cont != 0 ) ) 
 	{
 	  ret_str = fgets(tmp, 256, xd->data_file);
-
 	  
 	  if ( ret_str == NULL)
           {
@@ -234,6 +229,8 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
           {
              ret = (int)strlen (ret_str);
           }
+
+	  
 	  
 	  if ( ret == -1 )
 	    {
@@ -245,7 +242,9 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 	    }
 	  else 
 	    {
+
 	      ret = xnee_expression_handle_project(xd, ret_str);
+/* 	      ret = xnee_expression_handle_session(xd, ret_str, &xindata); */
 
 	      if ( (ret == XNEE_REPLAY_DATA) || 
 		   (ret == XNEE_PRIMITIVE_DATA) || 
@@ -261,19 +260,25 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 		  
 		  xnee_verbose((xd, "REPLAY DATA coming up .... %s \n",
 				ret_str));
+
+		  /* Make sure SYNTAX ERRROR is not forgotten */
+		  if (ret==XNEE_SYNTAX_ERROR)
+		    {
+		      XNEE_RETURN_IF_ERR (ret);  
+		    }
+
 		  break ; 
 		}
 	    }
 	}
-       ret = xnee_set_ranges(xd);
-       XNEE_RETURN_IF_ERR (ret);
+/*        ret = xnee_set_ranges(xd); */
     }
 
   if ( 
       (read_mode==XNEE_REPLAY_READ_REPLAY_DATA) || 
       (read_mode==XNEE_REPLAY_READ_ALL_DATA))
     {
-	
+      
       ret = xnee_set_ranges(xd);
       XNEE_RETURN_IF_ERR (ret);
 
@@ -335,6 +340,7 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
               }
 	      
 	      
+	
 	      /* Interrupt variable set? */
 	      if (xnee_get_interrupt_action(xd))
 		{
@@ -656,11 +662,13 @@ xnee_replay_dispatch (XPointer type_ref, XRecordInterceptData *data)
   XWindowAttributes window_attributes_return;
   int ret;
 
-  if (!data->data)
+
+  if (data->data==NULL)
     {
       return;
     }
 
+
   xrec_data  = (XRecordDatum *) (data->data) ;
   type       = (int) xrec_data->type ;
   xd         = (xnee_data*) (type_ref);
